#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2010 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Runtime.Serialization;
using HeuristicLab.Common;

namespace HeuristicLab.Services.Hive.Common.DataTransfer {
  [DataContract]
  [Serializable]
  public class Slave : Resource {
    [DataMember]
    public int? Cores { get; set; }
    [DataMember]
    public int? FreeCores { get; set; }
    [DataMember]
    public int? CpuSpeed { get; set; }
    [DataMember]
    public int? Memory { get; set; }
    [DataMember]
    public int? FreeMemory { get; set; }
    [DataMember]
    public SlaveState SlaveState { get; set; }
    [DataMember]
    public CalendarState CalendarSyncState { get; set; }
    [DataMember]
    public Guid? SlaveConfigId { get; set; }
    [DataMember]
    public bool IsAllowedToCalculate { get; set; }

    public Slave() {
      SlaveState = DataTransfer.SlaveState.Idle;
    }

    public override string ToString() {
      return base.ToString() + ", NrOfCores: " + Cores + ", NrOfFreeCores " + FreeCores + ", State: " + SlaveState;
    }

    public override IDeepCloneable Clone(Cloner cloner) {
      var clone = (Slave)base.Clone(cloner);
      clone.Cores = this.Cores;
      clone.FreeCores = this.FreeCores;
      clone.CpuSpeed = this.CpuSpeed;
      clone.Memory = this.Memory;
      clone.FreeMemory = this.FreeMemory;
      clone.SlaveState = this.SlaveState;
      clone.CalendarSyncState = this.CalendarSyncState;
      clone.SlaveConfigId = this.SlaveConfigId;
      clone.IsAllowedToCalculate = this.IsAllowedToCalculate;
      return clone;
    }
  }
}
